@@ -104,9 +104,9 @@ function setLabelForNode(aNode, aLabel, aIsLabelFlag)
 function commonDialogOnLoad()
 {
   // set the document title
-//@line 110 "/usr/obj/i386/xulrunner-1.8.1.19/mozilla/toolkit/content/commonDialog.js"
+//@line 110 "/usr/obj/i386/xulrunner-1.9.0.14/mozilla/toolkit/content/commonDialog.js"
   document.title = gCommonDialogParam.GetString(12);
-//@line 112 "/usr/obj/i386/xulrunner-1.8.1.19/mozilla/toolkit/content/commonDialog.js"
+//@line 112 "/usr/obj/i386/xulrunner-1.9.0.14/mozilla/toolkit/content/commonDialog.js"
 
   // set the number of command buttons
   var nButtons = gCommonDialogParam.GetInt(2);
@@ -122,9 +122,9 @@ function commonDialogOnLoad()
   }
 
   // display the main text
-  var messageParent = document.getElementById("info.box").getElementsByTagName('description')[0];
   // XXX the substr(0, 10000) part is a workaround for bug 317334
-  messageParent.textContent = gCommonDialogParam.GetString(0).substr(0, 10000);
+  var croppedMessage = gCommonDialogParam.GetString(0).substr(0, 10000);
+  setElementText("info.body", croppedMessage, true);
 
   setElementText("info.header", gCommonDialogParam.GetString(3), true);
 
@@ -168,9 +168,9 @@ function commonDialogOnLoad()
     // Set the default button and focus it on non-OS X systems
     var dButton = dlgButtons[gCommonDialogParam.GetInt(5)];
     document.documentElement.defaultButton = dButton;
-//@line 174 "/usr/obj/i386/xulrunner-1.8.1.19/mozilla/toolkit/content/commonDialog.js"
+//@line 174 "/usr/obj/i386/xulrunner-1.9.0.14/mozilla/toolkit/content/commonDialog.js"
     document.documentElement.getButton(dButton).focus();
-//@line 176 "/usr/obj/i386/xulrunner-1.8.1.19/mozilla/toolkit/content/commonDialog.js"
+//@line 176 "/usr/obj/i386/xulrunner-1.9.0.14/mozilla/toolkit/content/commonDialog.js"
   }
 
   if (gCommonDialogParam.GetInt(6) != 0) // delay button enable
@@ -219,7 +219,7 @@ function commonDialogFocus(aEvent)
     var script = "document.documentElement.getButton('accept').disabled = false; ";
     script += "document.documentElement.getButton('extra1').disabled = false; ";
     script += "document.documentElement.getButton('extra2').disabled = false;";
-    setTimeout(script, 1000);
+    setTimeout(script, 250);
   }
 }
 
@@ -260,9 +260,7 @@ function setElementText(aElementID, aValue, aChildNodeFlag)
 function setCheckbox(aChkMsg, aChkValue)
 {
   if (aChkMsg) {
-    // XXX Would love to use hidden instead of collapsed, but the checkbox
-    // fails to size itself properly when I do this.
-    document.getElementById("checkboxContainer").removeAttribute("collapsed");
+    unHideElementById("checkboxContainer");
     
     var checkboxElement = document.getElementById("checkbox");
     setLabelForNode(checkboxElement, aChkMsg);
