@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/i386/xulrunner-1.8.1.19/mozilla/toolkit/mozapps/extensions/content/list.js"
+//@line 39 "/usr/obj/i386/xulrunner-1.9.0.14/mozilla/toolkit/mozapps/extensions/content/list.js"
 
 const kXULNS = "http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul";
 const kDialog = "dialog";
@@ -77,12 +77,12 @@ function init() {
       var brandBundle = document.getElementById("brandBundle");
       var brandShortName = brandBundle.getString("brandShortName");
       params = {
-        message1: extensionsBundle.getFormattedString("blocklistNotifyMsg",
+        message1: extensionsBundle.getFormattedString("blocklistNotifyMsg2",
                                                       [brandShortName]),
-        message2: extensionsBundle.getFormattedString("blocklistRestartMsg",
+        message2: extensionsBundle.getFormattedString("blocklistRestartMsg2",
                                                       [brandShortName]),
         moreInfoURL: url,
-        title: extensionsBundle.getString("blocklistNotifyTitle")
+        title: extensionsBundle.getString("blocklistNotifyTitle2")
       };
       de.buttons = "extra1,cancel";
       button = de.getButton("cancel");
@@ -175,18 +175,6 @@ function restartApp() {
   if (cancelQuit.data)
     return;
 
-  // Notify all windows that an application quit has been granted.
-  os.notifyObservers(null, "quit-application-granted", null);
-
-  // Enumerate all windows and call shutdown handlers
-  var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
-                     .getService(Components.interfaces.nsIWindowMediator);
-  var windows = wm.getEnumerator(null);
-  while (windows.hasMoreElements()) {
-    var win = windows.getNext();
-    if (("tryToClose" in win) && !win.tryToClose())
-      return;
-  }
   Components.classes["@mozilla.org/toolkit/app-startup;1"].getService(nsIAppStartup)
             .quit(nsIAppStartup.eRestart | nsIAppStartup.eAttemptQuit);
 }
